package com.zkqy.system.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zkqy.system.mapper.BpmNodeHandleUserMapper;
import com.zkqy.system.entity.BpmNodeHandleUser;
import com.zkqy.system.service.IBpmNodeHandleUserService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 节点处理用户Service业务层处理
 *
 * @author hzh
 * @date 2023-10-26
 */
@Service
public class BpmNodeHandleUserServiceImpl implements IBpmNodeHandleUserService {

    @Autowired
    private BpmNodeHandleUserMapper bpmNodeHandleUserMapper;

    /**
     * 查询节点处理用户
     *
     * @param id 节点处理用户主键
     * @return 节点处理用户
     */
    @Override
    public BpmNodeHandleUser selectBpmNodeHandleUserById(Long id) {
        return bpmNodeHandleUserMapper.selectBpmNodeHandleUserById(id);
    }

    /**
     * 查询节点处理用户列表
     *
     * @param bpmNodeHandleUser 节点处理用户
     * @return 节点处理用户
     */
    @Override
    public List<BpmNodeHandleUser> selectBpmNodeHandleUserList(BpmNodeHandleUser bpmNodeHandleUser) {
        return bpmNodeHandleUserMapper.selectBpmNodeHandleUserList(bpmNodeHandleUser);
    }

    /**
     * 新增节点处理用户
     *
     * @param bpmNodeHandleUser 节点处理用户
     * @return 结果
     */
    @Override
    @Transactional
    public int insertBpmNodeHandleUser(List<BpmNodeHandleUser> bpmNodeHandleUser) {
        return bpmNodeHandleUserMapper.insertBpmNodeHandleUser(bpmNodeHandleUser);
    }

    /**
     * 修改节点处理用户
     *
     * @param bpmNodeHandleUser 节点处理用户
     * @return 结果
     */
    @Override
    public int updateBpmNodeHandleUser(List<BpmNodeHandleUser> bpmNodeHandleUser) {
        // 批量修改
        bpmNodeHandleUser.forEach(item -> {
            bpmNodeHandleUserMapper.updateBpmNodeHandleUser(item);
        });
        return 1;
    }

    /**
     * 批量删除节点处理用户
     *
     * @param ids 需要删除的节点处理用户主键
     * @return 结果
     */
    @Override
    public int deleteBpmNodeHandleUserByIds(Long[] ids) {
        return bpmNodeHandleUserMapper.deleteBpmNodeHandleUserByIds(ids);
    }

    /**
     * 删除节点处理用户信息
     *
     * @param id 节点处理用户主键
     * @return 结果
     */
    @Override
    public int deleteBpmNodeHandleUserById(Long id) {
        return bpmNodeHandleUserMapper.deleteBpmNodeHandleUserById(id);
    }

    @Override
    public BpmNodeHandleUser selectBpmNodeHandleUserByVirtuallyRole(String virtuallyRole) {
        return bpmNodeHandleUserMapper.selectBpmNodeHandleUserByVirtuallyRole(virtuallyRole);
    }
}
